@@ -1,19 +1,20 @@
 /*
  * Copyright © 2007-2009  Emmanuel Pacaud
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
+ * You should have received a copy of the GNU Lesser General
+ * Public License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
+ * Boston, MA 02111-1307, USA.
  *
  * Author:
  * 	Emmanuel Pacaud <emmanuel@gnome.org>
@@ -136,19 +137,33 @@ lsm_attribute_manager_set_attribute (LsmAttributeManager *manager,
 	attribute->value = g_strdup (value);
 
 	if (attribute->value != NULL) {
-		if (trait_class->from_string)
-			trait_class->from_string (ATTRIBUTE_TRAIT (attribute), (char *) value);
-	} else {
-		if (trait_class->init)
-			trait_class->init (ATTRIBUTE_TRAIT (attribute), attribute_infos->trait_default);
-		else
-			/* Simple memcpy for default init implementation, discarded by a NULL default value. */
-			if (attribute_infos->trait_default != NULL)
-				memcpy (ATTRIBUTE_TRAIT (attribute),
-					attribute_infos->trait_default,
-					trait_class->size);
+		if (trait_class->from_string) {
+			gboolean success;
+
+			success = trait_class->from_string (ATTRIBUTE_TRAIT (attribute), (char *) value);
+			if (success)
+				return TRUE;
+
+			if (trait_class->finalize)
+				trait_class->finalize (ATTRIBUTE_TRAIT (attribute));
+			g_free (attribute->value);
+			attribute->value = NULL;
+
+			lsm_debug_dom ("[LsmAttributeManager::set_attribute] Invalid attribute value %s='%s'",
+				   name, value);
+		} else
+			return TRUE;
 	}
 
+	if (trait_class->init)
+		trait_class->init (ATTRIBUTE_TRAIT (attribute), attribute_infos->trait_default);
+	else
+		/* Simple memcpy for default init implementation, discarded by a NULL default value. */
+		if (attribute_infos->trait_default != NULL)
+			memcpy (ATTRIBUTE_TRAIT (attribute),
+				attribute_infos->trait_default,
+				trait_class->size);
+
 	return TRUE;
 }
 
@@ -209,7 +224,7 @@ lsm_attribute_manager_serialize	(LsmAttributeManager *manager,
 	GHashTableIter iter;
 	char *c_string;
 	gpointer key, value;
-	gboolean is_first = TRUE;
+	gboolean attribute_found = FALSE;
 
 	g_return_val_if_fail (manager != NULL, NULL);
 
@@ -220,20 +235,26 @@ lsm_attribute_manager_serialize	(LsmAttributeManager *manager,
 		attribute_infos = value;
 		attribute = (void *)(instance + attribute_infos->attribute_offset);
 
-		if (is_first) {
-			g_string_append_printf (string, "%s=\"%s\"",
-						attribute_infos->name,
-						attribute->value);
-			is_first = FALSE;
-		} else {
-			g_string_append_printf (string, " %s=\"%s\"",
-						attribute_infos->name,
-						attribute->value);
+		if (attribute->value != NULL) {
+			if (!attribute_found) {
+				g_string_append_printf (string, "%s=\"%s\"",
+							attribute_infos->name,
+							attribute->value);
+				attribute_found = TRUE;
+			} else {
+				g_string_append_printf (string, " %s=\"%s\"",
+							attribute_infos->name,
+							attribute->value);
+			}
 		}
 	}
 
-	c_string = string->str;
+	if (!attribute_found) {
+		g_string_free (string, TRUE);
+		return NULL;
+	}
 
+	c_string = string->str;
 	g_string_free (string, FALSE);
 
 	return c_string;
