@@ -1,6 +1,6 @@
-/* lsmdomcharacterdata.c
+/* Lasem - SVG and Mathml library
  *
- * Copyright © 2007-2008  Emmanuel Pacaud
+ * Copyright © 2007-2010  Emmanuel Pacaud
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -21,13 +21,43 @@
  * 	Emmanuel Pacaud <emmanuel@gnome.org>
  */
 
+/**
+ * SECTION:lsmdomcharacterdata
+ * @short_description: Base class for DOM character data nodes
+ */
+
 #include <lsmdomcharacterdata.h>
+#include <lsmdebug.h>
+#include <string.h>
 
 static GObjectClass *parent_class = NULL;
 
+/* LsmDomNode implementation */
+
+static void
+lsm_dom_character_data_write_to_stream (LsmDomNode *self, GOutputStream *stream, GError **error)
+{
+	LsmDomCharacterData *character_data = LSM_DOM_CHARACTER_DATA (self);
+
+	if (character_data->data != NULL)
+		g_output_stream_write (stream, character_data->data, strlen (character_data->data), NULL, error);
+}
+
+static const char *
+lsm_dom_character_data_get_node_value (LsmDomNode* self)
+{
+	return lsm_dom_character_data_get_data (LSM_DOM_CHARACTER_DATA (self));
+}
+
+static void
+lsm_dom_character_data_set_node_value (LsmDomNode* self, const char *value)
+{
+	lsm_dom_character_data_set_data (LSM_DOM_CHARACTER_DATA (self), value);
+}
+
 /* LsmDomCharacterData implementation */
 
-char*
+const char *
 lsm_dom_character_data_get_data (LsmDomCharacterData* self)
 {
 	g_return_val_if_fail (LSM_IS_DOM_CHARACTER_DATA (self), NULL);
@@ -36,7 +66,7 @@ lsm_dom_character_data_get_data (LsmDomCharacterData* self)
 }
 
 void
-lsm_dom_character_data_set_data (LsmDomCharacterData* self, const char* value)
+lsm_dom_character_data_set_data (LsmDomCharacterData* self, const char * value)
 {
 	g_return_if_fail (LSM_IS_DOM_CHARACTER_DATA (self));
 	g_return_if_fail (value != NULL);
@@ -44,6 +74,8 @@ lsm_dom_character_data_set_data (LsmDomCharacterData* self, const char* value)
 	g_free (self->data);
 	self->data = g_strdup (value);
 
+	lsm_debug_dom ("[LsmDomCharacterData::set_data] Value = '%s'", value);
+
 	lsm_dom_node_changed (LSM_DOM_NODE (self));
 }
 
@@ -68,10 +100,15 @@ static void
 lsm_dom_character_data_class_init (LsmDomCharacterDataClass *character_data_class)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (character_data_class);
+	LsmDomNodeClass *node_class = LSM_DOM_NODE_CLASS (character_data_class);
 
 	parent_class = g_type_class_peek_parent (character_data_class);
 
 	object_class->finalize = lsm_dom_character_data_finalize;
+
+	node_class->write_to_stream = lsm_dom_character_data_write_to_stream;
+	node_class->set_node_value = lsm_dom_character_data_set_node_value;
+	node_class->get_node_value = lsm_dom_character_data_get_node_value;
 }
 
 G_DEFINE_ABSTRACT_TYPE (LsmDomCharacterData, lsm_dom_character_data, LSM_TYPE_DOM_NODE)
