@@ -1,6 +1,6 @@
-/* lsmdomnode.h
+/* Lasem - SVG and Mathml library
  *
- * Copyright © 2007-2008  Emmanuel Pacaud
+ * Copyright © 2007-2008 Emmanuel Pacaud
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -24,7 +24,8 @@
 #ifndef LSM_DOM_NODE_H
 #define LSM_DOM_NODE_H
 
-#include <lsmdom.h>
+#include <lsmdomtypes.h>
+#include <gio/gio.h>
 
 G_BEGIN_DECLS
 
@@ -71,10 +72,6 @@ struct _LsmDomNodeClass {
 	const char* 		(*get_node_value) 	(LsmDomNode* self);
 	void 			(*set_node_value) 	(LsmDomNode* self, const char* new_value);
 	LsmDomNodeType 		(*get_node_type) 	(LsmDomNode* self);
-#if 0
-	LsmDomNodeList* 	(*get_child_nodes) (LsmDomNode* self);
-	LsmDomNamedNodeMap* 	(*get_attributes) (LsmDomNode* self);
-#endif
 
 	/* Validation virtuals */
 
@@ -86,36 +83,37 @@ struct _LsmDomNodeClass {
 	void			(*pre_remove_child) 	(LsmDomNode *parent, LsmDomNode *child);
 	void			(*changed)		(LsmDomNode *self);
 	gboolean		(*child_changed)	(LsmDomNode *self, LsmDomNode *child);
+
+	void			(*write_to_stream)	(LsmDomNode *self, GOutputStream *stream, GError **error);
 };
 
 GType lsm_dom_node_get_type (void);
 
-const char* 		lsm_dom_node_get_node_name 		(LsmDomNode* self);
-const char* 		lsm_dom_node_get_node_value 		(LsmDomNode* self);
+const char * 		lsm_dom_node_get_node_name 		(LsmDomNode* self);
+const char * 		lsm_dom_node_get_node_value 		(LsmDomNode* self);
 void 			lsm_dom_node_set_node_value 		(LsmDomNode* self, const char* new_value);
 LsmDomNodeType 		lsm_dom_node_get_node_type 		(LsmDomNode* self);
-LsmDomNode* 		lsm_dom_node_get_parent_node 		(LsmDomNode* self);
+LsmDomNode * 		lsm_dom_node_get_parent_node 		(LsmDomNode* self);
+LsmDomNodeList *	lsm_dom_node_get_child_nodes 		(LsmDomNode* self);
+LsmDomNode * 		lsm_dom_node_get_first_child 		(LsmDomNode* self);
+LsmDomNode * 		lsm_dom_node_get_last_child 		(LsmDomNode* self);
+LsmDomNode * 		lsm_dom_node_get_previous_sibling 	(LsmDomNode* self);
+LsmDomNode * 		lsm_dom_node_get_next_sibling 		(LsmDomNode* self);
 #if 0
-LsmDomNodeList* 		lsm_dom_node_get_child_nodes 	(LsmDomNode* self);
+LsmDomNamedNodeMap * 	lsm_dom_node_get_attributes 		(LsmDomNode* self);
 #endif
-LsmDomNode* 		lsm_dom_node_get_first_child 		(LsmDomNode* self);
-LsmDomNode* 		lsm_dom_node_get_last_child 		(LsmDomNode* self);
-LsmDomNode* 		lsm_dom_node_get_previous_sibling 	(LsmDomNode* self);
-LsmDomNode* 		lsm_dom_node_get_next_sibling 		(LsmDomNode* self);
-#if 0
-LsmDomNamedNodeMap* 	lsm_dom_node_get_attributes 	(LsmDomNode* self);
-#endif
-LsmDomNode* 		lsm_dom_node_insert_before		(LsmDomNode* self, LsmDomNode* new_child, LsmDomNode* ref_child);
-LsmDomNode* 		lsm_dom_node_replace_child 		(LsmDomNode* self, LsmDomNode* new_child, LsmDomNode* old_child);
-LsmDomNode* 		lsm_dom_node_append_child 		(LsmDomNode* self, LsmDomNode* new_child);
-LsmDomNode* 		lsm_dom_node_remove_child 		(LsmDomNode* self, LsmDomNode* old_child);
+LsmDomNode * 		lsm_dom_node_insert_before		(LsmDomNode* self, LsmDomNode* new_child, LsmDomNode* ref_child);
+LsmDomNode * 		lsm_dom_node_replace_child 		(LsmDomNode* self, LsmDomNode* new_child, LsmDomNode* old_child);
+LsmDomNode * 		lsm_dom_node_append_child 		(LsmDomNode* self, LsmDomNode* new_child);
+LsmDomNode * 		lsm_dom_node_remove_child 		(LsmDomNode* self, LsmDomNode* old_child);
 gboolean 		lsm_dom_node_has_child_nodes 		(LsmDomNode* self);
 
 void 			lsm_dom_node_changed 			(LsmDomNode *self);
 
-LsmDomDocument*		lsm_dom_node_get_owner_document 	(LsmDomNode* self);
+LsmDomDocument *	lsm_dom_node_get_owner_document 	(LsmDomNode* self);
 
-void 			lsm_dom_node_dump 			(LsmDomNode *self);
+void			lsm_dom_node_write_to_stream		(LsmDomNode *self, GOutputStream *stream,
+								 GError **error);
 
 G_END_DECLS
 
