@@ -1,6 +1,6 @@
-/* lsmdomtext.h
+/* Lasem - SVG and Mathml library
  *
- * Copyright © 2007-2008  Emmanuel Pacaud
+ * Copyright © 2007-2008 Emmanuel Pacaud
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -24,7 +24,6 @@
 #ifndef LSM_DOM_TEXT_H
 #define LSM_DOM_TEXT_H
 
-#include <lsmdom.h>
 #include <lsmdomcharacterdata.h>
 
 G_BEGIN_DECLS
