@@ -1,32 +1,104 @@
-/*
+/* Lasem - SVG and Mathml library
+ *
  * Copyright © 2009 Emmanuel Pacaud
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
+ * You should have received a copy of the GNU Lesser General
+ * Public License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
+ * Boston, MA 02111-1307, USA.
  *
  * Author:
  * 	Emmanuel Pacaud <emmanuel@gnome.org>
  */
 
+/**
+ * SECTION:lsmdomview
+ * @short_description: Base class for DOM views
+ */
+
 #include <lsmdebug.h>
 #include <lsmdomdocument.h>
 #include <lsmdomview.h>
 
 static GObjectClass *parent_class;
 
+double
+lsm_dom_view_get_resolution (LsmDomView *self)
+{
+	g_return_val_if_fail (LSM_IS_DOM_VIEW (self), 0.0);
+
+	return self->resolution_ppi;
+}
+
 void
-lsm_dom_view_get_size (LsmDomView *view, double *width, double *height)
+lsm_dom_view_set_resolution (LsmDomView *self, double ppi)
+{
+	g_return_if_fail (LSM_IS_DOM_VIEW (self));
+
+	if (ppi < 0.0)
+		self->resolution_ppi = LSM_DOM_VIEW_DEFAULT_RESOLUTION;
+	else
+		self->resolution_ppi = ppi;
+}
+
+void
+lsm_dom_view_set_viewport (LsmDomView *self, const LsmBox *viewport_pt)
+{
+	g_return_if_fail (LSM_IS_DOM_VIEW (self));
+	g_return_if_fail (viewport_pt != NULL);
+
+	self->viewport_pt = *viewport_pt;
+}
+
+void
+lsm_dom_view_set_viewport_pixels (LsmDomView *self, const LsmBox *viewport)
+{
+	g_return_if_fail (LSM_IS_DOM_VIEW (self));
+	g_return_if_fail (viewport != NULL);
+
+	self->viewport_pt.x      = viewport->x      * 72.0 / self->resolution_ppi;
+	self->viewport_pt.y      = viewport->y      * 72.0 / self->resolution_ppi;
+	self->viewport_pt.width  = viewport->width  * 72.0 / self->resolution_ppi;
+	self->viewport_pt.height = viewport->height * 72.0 / self->resolution_ppi;
+}
+
+LsmBox
+lsm_dom_view_get_viewport (LsmDomView *self)
+{
+	static const LsmBox null_viewport = {0, 0, 0, 0};
+
+	g_return_val_if_fail (LSM_IS_DOM_VIEW (self), null_viewport);
+
+	return self->viewport_pt;
+}
+
+LsmBox
+lsm_dom_view_get_viewport_pixels (LsmDomView *self)
+{
+	LsmBox viewport = {0, 0, 0, 0};
+
+	g_return_val_if_fail (LSM_IS_DOM_VIEW (self), viewport);
+
+	viewport.x      = self->viewport_pt.x      * self->resolution_ppi / 72.0;
+	viewport.y      = self->viewport_pt.y      * self->resolution_ppi / 72.0;
+	viewport.width  = self->viewport_pt.width  * self->resolution_ppi / 72.0;
+	viewport.height = self->viewport_pt.height * self->resolution_ppi / 72.0;
+
+	return viewport;
+}
+
+void
+lsm_dom_view_get_size (LsmDomView *view, double *width, double *height, double *baseline)
 {
 	LsmDomViewClass *view_class;
 	double dummy_width = 0.0;
@@ -42,69 +114,39 @@ lsm_dom_view_get_size (LsmDomView *view, double *width, double *height)
 
 	view_class = LSM_DOM_VIEW_GET_CLASS (view);
 	if (view_class->measure != NULL)
-		view_class->measure (view, width, height);
+		view_class->measure (view, width, height, baseline);
 }
 
 void
-lsm_dom_view_get_size_pixels (LsmDomView *view, unsigned int *width, unsigned int *height)
+lsm_dom_view_get_size_pixels (LsmDomView *view, unsigned int *width, unsigned int *height, unsigned int *baseline)
 {
 	double resolution_ppi;
 	double width_pt;
 	double height_pt;
+	double baseline_pt;
 
 	g_return_if_fail (LSM_IS_DOM_VIEW (view));
 	g_return_if_fail (view->document != NULL);
 
-	resolution_ppi = lsm_dom_document_get_resolution (view->document);
+	resolution_ppi = view->resolution_ppi;
 	g_return_if_fail (resolution_ppi > 0.0);
 
 	width_pt =  width  != NULL ? *width  * 72.0 / resolution_ppi : 0.0;
 	height_pt = height != NULL ? *height * 72.0 / resolution_ppi : 0.0;
+	baseline_pt = baseline != NULL? *baseline * 72.0 /resolution_ppi : 0.0;
 
-	lsm_dom_view_get_size (view, &width_pt, &height_pt);
+	lsm_dom_view_get_size (view, &width_pt, &height_pt,&baseline_pt);
 
 	if (width != NULL)
 		*width =  (double) (0.5 + width_pt  * resolution_ppi / 72.0);
 	if (height != NULL)
 		*height = (double) (0.5 + height_pt * resolution_ppi / 72.0);
+	if (baseline != NULL)
+		*baseline = (double) (0.5 + baseline_pt * resolution_ppi / 72.0);
 }
 
-void
-lsm_dom_view_render (LsmDomView *view, double x, double y)
-{
-	LsmDomViewClass *view_class;
-	double resolution_ppi;
-
-	g_return_if_fail (LSM_IS_DOM_VIEW (view));
-	g_return_if_fail (LSM_IS_DOM_DOCUMENT (view->document));
-	g_return_if_fail (view->cairo != NULL);
-
-	resolution_ppi = lsm_dom_document_get_resolution (view->document);
-
-	cairo_save (view->cairo);
-
-	cairo_translate (view->cairo, x, y);
-
-	view_class = LSM_DOM_VIEW_GET_CLASS (view);
-	if (view_class->render != NULL)
-		view_class->render (view);
-
-	cairo_restore (view->cairo);
-
-	lsm_debug ("[LsmDomView::render] cairo status = %s",
-		   cairo_status_to_string (cairo_status (view->cairo)));
-}
-
-void
-lsm_dom_view_set_debug (LsmDomView *view, gboolean debug)
-{
-	g_return_if_fail (LSM_IS_DOM_VIEW (view));
-
-	view->debug = debug;
-}
-
-void
-lsm_dom_view_set_cairo (LsmDomView *view, cairo_t *cairo)
+static void
+lsm_dom_view_set_cairo_context (LsmDomView *view, cairo_t *cairo)
 {
 	PangoContext *context;
 	PangoFontDescription *font_description;
@@ -157,6 +199,33 @@ lsm_dom_view_set_cairo (LsmDomView *view, cairo_t *cairo)
 	cairo_font_options_destroy (font_options);
 }
 
+void
+lsm_dom_view_render (LsmDomView *view, cairo_t *cairo, double x, double y)
+{
+	LsmDomViewClass *view_class;
+
+	g_return_if_fail (LSM_IS_DOM_VIEW (view));
+	g_return_if_fail (LSM_IS_DOM_DOCUMENT (view->document));
+	g_return_if_fail (cairo != NULL);
+
+	lsm_dom_view_set_cairo_context (view, cairo);
+
+	cairo_save (view->cairo);
+
+	cairo_translate (view->cairo, x, y);
+
+	view_class = LSM_DOM_VIEW_GET_CLASS (view);
+	if (view_class->render != NULL)
+		view_class->render (view);
+
+	cairo_restore (view->cairo);
+
+	lsm_debug_render ("[LsmDomView::render] cairo status = %s",
+			  cairo_status_to_string (cairo_status (view->cairo)));
+
+	lsm_dom_view_set_cairo_context (view, NULL);
+}
+
 void
 lsm_dom_view_set_document (LsmDomView *view, LsmDomDocument *document)
 {
@@ -182,6 +251,12 @@ lsm_dom_view_init (LsmDomView *view)
 	PangoContext *pango_context;
 	cairo_font_options_t *font_options;
 
+	view->resolution_ppi = LSM_DOM_VIEW_DEFAULT_RESOLUTION;
+	view->viewport_pt.x = 0;
+	view->viewport_pt.y = 0;
+	view->viewport_pt.width  = LSM_DOM_VIEW_DEFAULT_VIEWBOX_WIDTH;
+	view->viewport_pt.height = LSM_DOM_VIEW_DEFAULT_VIEWBOX_HEIGHT;
+
 	view->font_description = pango_font_description_new ();
 
 	font_map = pango_cairo_font_map_get_default ();
@@ -216,7 +291,8 @@ lsm_dom_view_finalize (GObject *object)
 {
 	LsmDomView *view = LSM_DOM_VIEW (object);
 
-	g_object_unref (view->document);
+	if (view->document)
+		g_object_unref (view->document);
 
 	if (view->pango_layout != NULL)
 		g_object_unref (view->pango_layout);
