@@ -1,6 +1,6 @@
-/* lsmmathmldocument.h
+/* Lasem - SVG and Mathml library
  *
- * Copyright © 2007-2008  Emmanuel Pacaud
+ * Copyright © 2007-2008 Emmanuel Pacaud
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -24,7 +24,7 @@
 #ifndef LSM_MATHML_DOCUMENT_H
 #define LSM_MATHML_DOCUMENT_H
 
-#include <lsmmathml.h>
+#include <lsmmathmltypes.h>
 #include <lsmdomdocument.h>
 
 G_BEGIN_DECLS
@@ -48,7 +48,7 @@ struct _LsmMathmlDocumentClass {
 
 GType lsm_mathml_document_get_type (void);
 
-LsmMathmlDocument *	lsm_mathml_document_new 		(void);
+LsmDomDocument *	lsm_mathml_document_new 		(void);
 LsmMathmlMathElement * 	lsm_mathml_document_get_root_element 	(const LsmMathmlDocument *document);
 
 LsmMathmlDocument * 	lsm_mathml_document_new_from_itex	(const char *itex, int size, GError **error);
