@@ -1,6 +1,6 @@
-/* lsmmathmlenums.h
+/* Lasem - SVG and Mathml library
  *
- * Copyright © 2007-2008  Emmanuel Pacaud
+ * Copyright © 2007-2008 Emmanuel Pacaud
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -24,7 +24,7 @@
 #ifndef LSM_MATHML_ENUMS_H
 #define LSM_MATHML_ENUMS_H
 
-#include <lsmmathml.h>
+#include <glib-object.h>
 
 G_BEGIN_DECLS
 
