@@ -125,7 +125,7 @@ lsm_mathml_radical_element_measure (LsmMathmlElement *self, LsmMathmlView *view,
 
 	lsm_mathml_bbox_add_horizontally (&self->bbox, &radical->bbox);
 
-	lsm_debug ("measure", "[LsmMathmlRadicalElement::measure] Radical bbox w = %g, h = %g, d = %g",
+	lsm_debug_measure ("[LsmMathmlRadicalElement::measure] Radical bbox w = %g, h = %g, d = %g",
 		    radical->bbox.width, radical->bbox.height, radical->bbox.depth);
 
 	if (radical->type == LSM_MATHML_RADICAL_ELEMENT_TYPE_ROOT) {
@@ -141,7 +141,7 @@ lsm_mathml_radical_element_measure (LsmMathmlElement *self, LsmMathmlView *view,
 			radical->radical_x_offset = child_bbox.width - x_offset;
 			self->bbox.width += radical->radical_x_offset;
 
-			lsm_debug ("measure", "[LsmMathmlRadicalElement::measure] y_offset = %g", y_offset);
+			lsm_debug_measure ("[LsmMathmlRadicalElement::measure] y_offset = %g", y_offset);
 
 			height = self->bbox.height - y_offset + child_bbox.height + child_bbox.depth;
 			if (height > self->bbox.height)
@@ -149,7 +149,7 @@ lsm_mathml_radical_element_measure (LsmMathmlElement *self, LsmMathmlView *view,
 
 			radical->order_y_offset = - self->bbox.height + child_bbox.height;
 
-			lsm_debug ("measure", "[LsmMathmlRadicalElement::measure] order_y_offset = %g",
+			lsm_debug_measure ("[LsmMathmlRadicalElement::measure] order_y_offset = %g",
 				    radical->order_y_offset);
 		}
 	}
