@@ -130,7 +130,7 @@ lsm_mathml_view_show_layout (LsmMathmlView *view,
 			  const PangoRectangle *ink_rect,
 			  const PangoRectangle * rect)
 {
-	if (view->dom_view.debug) {
+	if (lsm_debug_check (&lsm_debug_category_render, LSM_DEBUG_LEVEL_DEBUG)) {
 		cairo_t *cairo;
 
 		cairo = view->dom_view.cairo;
@@ -186,7 +186,7 @@ lsm_mathml_view_measure_axis_offset (LsmMathmlView *view,
 
 	axis_offset = pango_units_to_double (- 0.5 * ink_rect.height - ink_rect.y + baseline);
 
-	lsm_debug ("measure", "[LsmMathmlView::measure_axis_offset] offset = %g (%g %%)",
+	lsm_debug_measure ("[LsmMathmlView::measure_axis_offset] offset = %g (%g %%)",
 		   axis_offset, axis_offset / math_size);
 
 	return axis_offset;
@@ -251,7 +251,7 @@ lsm_mathml_view_show_text (LsmMathmlView *view,
 	if (text == NULL || strlen (text) < 1)
 		return;
 
-	lsm_debug ("render", "[LsmMathmlView::show_text] '%s' at %g, %g (size = %g) %s",
+	lsm_debug_render ("[LsmMathmlView::show_text] '%s' at %g, %g (size = %g) %s",
 		   text, x, y, style->math_size,
 		   lsm_mathml_variant_to_string (style->math_variant));
 
@@ -267,7 +267,7 @@ lsm_mathml_view_show_text (LsmMathmlView *view,
 
 	cairo_save (cairo);
 
-	if (view->dom_view.debug) {
+	if (lsm_debug_check (&lsm_debug_category_dom, LSM_DEBUG_LEVEL_DEBUG)) {
 		cairo_set_source_rgba (cairo, 1.0, 0.0, 0.0, 0.2);
 		cairo_arc (cairo, x, y, 1.0, 0.0, 2.0 * M_PI);
 		cairo_fill (cairo);
@@ -350,7 +350,7 @@ lsm_mathml_view_measure_operator (LsmMathmlView *view,
 	pango_layout = view->dom_view.measure_pango_layout;
 
 	if (is_stretch_bbox_defined)
-		lsm_debug ("render", "[LsmMathmlView::measure_operator] Stretch bbox w = %g, h = %g, d = %g",
+		lsm_debug_render ("[LsmMathmlView::measure_operator] Stretch bbox w = %g, h = %g, d = %g",
 			   stretch_bbox->width, stretch_bbox->height, stretch_bbox->depth);
 
 	glyph = lsm_mathml_glyph_table_find_operator_glyph (text);
@@ -359,7 +359,7 @@ lsm_mathml_view_measure_operator (LsmMathmlView *view,
 							 pango_layout, &ink_rect, NULL, &baseline);
 		flags = 0;
 
-		lsm_debug ("render", "[LsmMathmlView::measure_operator] operator = %s", text);
+		lsm_debug_render ("[LsmMathmlView::measure_operator] operator = %s", text);
 
 	} else {
 		PangoLayoutIter *iter;
@@ -390,9 +390,8 @@ lsm_mathml_view_measure_operator (LsmMathmlView *view,
 			height = pango_units_to_double (ink_rect.height);
 			width = pango_units_to_double (ink_rect.width);
 
-			lsm_debug ("render",
-				   "[LsmMathmlView::measure_operator] Glyph #%i -> width = %g, height = %g", i,
-				    width, height);
+			lsm_debug_render ( "[LsmMathmlView::measure_operator] Glyph #%i -> width = %g, height = %g",
+					   i, width, height);
 
 			if (!is_stretch_bbox_defined) {
 				found = TRUE;
@@ -414,7 +413,7 @@ lsm_mathml_view_measure_operator (LsmMathmlView *view,
 		}
 
 		if (found)
-			lsm_debug ("render", "[LsmMathmlView::measure_operator] Found sized glyph #%i", i);
+			lsm_debug_render ("[LsmMathmlView::measure_operator] Found sized glyph #%i", i);
 
 		iter = pango_layout_get_iter (pango_layout);
 		baseline = pango_layout_iter_get_baseline (iter);
@@ -484,7 +483,7 @@ lsm_mathml_view_show_operator (LsmMathmlView *view,
 	pango_layout = view->dom_view.measure_pango_layout;
 
 	if (stretch_bbox->is_defined)
-		lsm_debug ("render", "[LsmMathmlView::show_operator] Stretch bbox w = %g, h = %g, d = %g",
+		lsm_debug_render ("[LsmMathmlView::show_operator] Stretch bbox w = %g, h = %g, d = %g",
 			   stretch_bbox->width, stretch_bbox->height, stretch_bbox->depth);
 
 	glyph = lsm_mathml_glyph_table_find_operator_glyph (text);
@@ -515,7 +514,7 @@ lsm_mathml_view_show_operator (LsmMathmlView *view,
 			pango_layout_set_font_description (pango_layout, font_description);
 			pango_layout_get_extents (pango_layout, &ink_rect, NULL);
 
-			lsm_debug ("render", "[LsmMathmlView::show_operator] Glyph #%i -> width = %g, height = %g", i,
+			lsm_debug_render ("[LsmMathmlView::show_operator] Glyph #%i -> width = %g, height = %g", i,
 				   pango_units_to_double (ink_rect.width),
 				   pango_units_to_double (ink_rect.height));
 
@@ -541,14 +540,14 @@ lsm_mathml_view_show_operator (LsmMathmlView *view,
 		}
 
 		if (found)
-			lsm_debug ("render", "[LsmMathmlView::show_operator] Found sized glyph #%i", i);
+			lsm_debug_render ("[LsmMathmlView::show_operator] Found sized glyph #%i", i);
 
 		iter = pango_layout_get_iter (pango_layout);
 		baseline = pango_layout_iter_get_baseline (iter);
 		pango_layout_iter_free (iter);
 	}
 
-	lsm_debug ("render", "[LsmMathmlView::show_operator] '%s' at %g, %g (size = %g) %s - %s",
+	lsm_debug_render ("[LsmMathmlView::show_operator] '%s' at %g, %g (size = %g) %s - %s",
 		    text, x, y, style->math_size,
 		    style->math_family,
 		    lsm_mathml_variant_to_string (style->math_variant));
@@ -563,7 +562,7 @@ lsm_mathml_view_show_operator (LsmMathmlView *view,
 
 	cairo_save (cairo);
 
-	if (view->dom_view.debug) {
+	if (lsm_debug_check (&lsm_debug_category_render, LSM_DEBUG_LEVEL_DEBUG)) {
 		cairo_set_source_rgba (cairo, 1.0, 0.0, 0.0, 0.1);
 		cairo_arc (cairo, x, y, 1.0, 0.0, 2.0 * M_PI);
 		cairo_fill (cairo);
@@ -837,7 +836,7 @@ lsm_mathml_view_show_bbox (LsmMathmlView *view, double x, double y, const LsmMat
 
 	cairo = view->dom_view.cairo;
 
-	if (view->dom_view.debug) {
+	if (lsm_debug_check (&lsm_debug_category_render, LSM_DEBUG_LEVEL_DEBUG)) {
 		cairo_move_to (cairo, x, y);
 		cairo_set_source_rgba (cairo, 0,0,1,0.1);
 		cairo_rectangle (cairo, x, y, bbox->width, -bbox->height);
@@ -934,7 +933,7 @@ lsm_mathml_view_show_fraction_line (LsmMathmlView *view,
 }
 
 static const LsmMathmlBbox *
-_view_measure (LsmMathmlView *view, double *width, double *height)
+_view_measure (LsmMathmlView *view, double *width, double *height, double *baseline)
 {
 	LsmMathmlMathElement *math_element;
 	const LsmMathmlBbox *bbox;
@@ -952,15 +951,17 @@ _view_measure (LsmMathmlView *view, double *width, double *height)
 			*width = bbox->width;
 		if (height != NULL)
 			*height = bbox->height + bbox->depth;
+		if (baseline != NULL)
+			*baseline = bbox->height;
 	}
 
 	return bbox;
 }
 
 static void
-lsm_mathml_view_measure (LsmDomView *dom_view, double *width, double *height)
+lsm_mathml_view_measure (LsmDomView *dom_view, double *width, double *height, double *baseline)
 {
-	_view_measure (LSM_MATHML_VIEW (dom_view), width, height);
+	_view_measure (LSM_MATHML_VIEW (dom_view), width, height, baseline);
 }
 
 static void
@@ -976,9 +977,9 @@ lsm_mathml_view_render (LsmDomView *dom_view)
 	if (math_element == NULL)
 		return;
 
-	resolution_ppi = lsm_dom_document_get_resolution (view->dom_view.document);
+	resolution_ppi = lsm_dom_view_get_resolution (dom_view);
 
-	bbox = _view_measure (view, NULL, NULL);
+	bbox = _view_measure (view, NULL, NULL, NULL);
 
 	lsm_mathml_math_element_layout (math_element, view, bbox);
 
@@ -990,7 +991,7 @@ lsm_mathml_view_render (LsmDomView *dom_view)
 
 	lsm_mathml_math_element_render (math_element, view);
 
-	lsm_debug ("render", "[LsmMathmlView::render] cairo status = %s",
+	lsm_debug_render ("[LsmMathmlView::render] cairo status = %s",
 		   cairo_status_to_string (cairo_status (cairo)));
 }
 
