@@ -1,4 +1,5 @@
-/*
+/* Lasem - SVG and Mathml library
+ *
  * Copyright © 2007-2009 Emmanuel Pacaud
  *
  * This library is free software; you can redistribute it and/or
@@ -19,16 +20,17 @@
  * Author:
  * 	Emmanuel Pacaud <emmanuel@gnome.org>
  */
+
 #ifndef LSM_PROPERTIES_H
 #define LSM_PROPERTIES_H
 
-#include <lsm.h>
+#include <lsmtypes.h>
 #include <lsmtraits.h>
 
 G_BEGIN_DECLS
 
-#define LSM_PROPERTY_OFFSET_TO_ID(structure,member) offsetof (structure, member) / sizeof (void *)
-#define LSM_PROPERTY_ID_TO_OFFSET(id) id * sizeof (void *)
+#define LSM_PROPERTY_OFFSET_TO_ID(structure,member) (offsetof (structure, member) / sizeof (void *))
+#define LSM_PROPERTY_ID_TO_OFFSET(id) ((id) * sizeof (void *))
 
 typedef struct {
 	guint16	id;
