@@ -1,4 +1,5 @@
-/*
+/* Lasem - SVG and Mathml library
+ *
  * Copyright © 2009 Emmanuel Pacaud
  *
  * This library is free software; you can redistribute it and/or
@@ -23,9 +24,16 @@
 #include <lsmsvggradientelement.h>
 #include <lsmsvgstopelement.h>
 #include <lsmsvgview.h>
+#include <lsmdomdocument.h>
 #include <lsmdebug.h>
 #include <stdio.h>
 
+static const LsmSvgGradientElementAttributes default_attributes = {
+	.transform = {1.0, 0.0, 0.0, 1.0, 0.0, 0.0, LSM_SVG_MATRIX_FLAGS_IDENTITY},
+	.units = LSM_SVG_PATTERN_UNITS_OBJECT_BOUNDING_BOX,
+	.spread_method = LSM_SVG_SPREAD_METHOD_PAD,
+};
+
 static GObjectClass *parent_class;
 
 /* GdomNode implementation */
@@ -42,23 +50,36 @@ static void
 lsm_svg_gradient_element_render (LsmSvgElement *self, LsmSvgView *view)
 {
 	LsmSvgGradientElement *gradient = LSM_SVG_GRADIENT_ELEMENT (self);
+	LsmSvgGradientElement *referenced_gradient;
 	LsmSvgGradientElementClass *gradient_class = LSM_SVG_GRADIENT_ELEMENT_GET_CLASS (self);
+	LsmDomNode *node;
 
 	if (!gradient->enable_rendering)
 		return;
 
 	gradient->enable_rendering = FALSE;
 
-	g_return_if_fail (gradient_class->create_gradient != NULL);
+	referenced_gradient = gradient_class->create_gradient (self, view);
 
-	gradient_class->create_gradient (self, view);
+	if (referenced_gradient == NULL)
+		return;
+
+	lsm_debug_render ("[LsmSvgElement::render] transform %g, %g, %g, %g, %g, %g",
+		   gradient->transform.matrix.a,
+		   gradient->transform.matrix.b,
+		   gradient->transform.matrix.c,
+		   gradient->transform.matrix.d,
+		   gradient->transform.matrix.e,
+		   gradient->transform.matrix.f);
 
 	lsm_svg_view_set_gradient_properties (view,
 					      gradient->spread_method.value,
 					      gradient->units.value,
 					      &gradient->transform.matrix);
 
-	LSM_SVG_ELEMENT_CLASS (parent_class)->render (self, view);
+	for (node = LSM_DOM_NODE (referenced_gradient)->first_child; node != NULL; node = node->next_sibling)
+		if (LSM_IS_SVG_ELEMENT (node))
+		    lsm_svg_element_render (LSM_SVG_ELEMENT (node), view);
 }
 
 static void
@@ -69,39 +90,37 @@ lsm_svg_gradient_element_enable_rendering (LsmSvgElement *element)
 
 /* LsmSvgGradientElement implementation */
 
-static const LsmSvgPatternUnits units_default = LSM_SVG_PATTERN_UNITS_OBJECT_BOUNDING_BOX;
-static const LsmSvgSpreadMethod spread_method_default = LSM_SVG_SPREAD_METHOD_PAD;
-static const LsmSvgMatrix matrix_default = {1.0, 0.0, 0.0, 1.0, 0.0, 0.0, LSM_SVG_MATRIX_FLAGS_IDENTITY};
 
 static void
 lsm_svg_gradient_element_init (LsmSvgGradientElement *self)
 {
 	self->enable_rendering = FALSE;
-	self->units.value = units_default;
-	self->spread_method.value = spread_method_default;
-	lsm_svg_matrix_init_identity (&self->transform.matrix);
+
+	self->units.value = default_attributes.units;
+	self->spread_method.value = default_attributes.spread_method;
+	self->transform.matrix = default_attributes.transform;
 }
 
 /* LsmSvgGradientElement class */
 
 static const LsmAttributeInfos lsm_svg_gradient_element_attribute_infos[] = {
-	{
-		.name = "gradientUnits",
-		.attribute_offset = offsetof (LsmSvgGradientElement, units),
-		.trait_class = &lsm_svg_pattern_units_trait_class,
-		.trait_default = &units_default
-	},
 	{
 		.name = "gradientTransform",
 		.attribute_offset = offsetof (LsmSvgGradientElement, transform),
 		.trait_class = &lsm_svg_matrix_trait_class,
-		.trait_default = &matrix_default
+		.trait_default = &default_attributes.transform
+	},
+	{
+		.name = "gradientUnits",
+		.attribute_offset = offsetof (LsmSvgGradientElement, units),
+		.trait_class = &lsm_svg_pattern_units_trait_class,
+		.trait_default = &default_attributes.units
 	},
 	{
 		.name = "spreadMethod",
 		.attribute_offset = offsetof (LsmSvgGradientElement, spread_method),
 		.trait_class = &lsm_svg_spread_method_trait_class,
-		.trait_default = &spread_method_default
+		.trait_default = &default_attributes.spread_method
 	},
 	{
 		.name = "xlink:href",
