@@ -68,13 +68,18 @@ lsm_svg_radial_gradient_element_get_node_name (LsmDomNode *node)
 LsmSvgGradientElement *
 lsm_svg_radial_gradient_element_inherit_referenced (LsmDomDocument *owner,
 						    LsmSvgGradientElement *gradient,
-						    LsmSvgRadialGradientElementAttributes *attributes)
+						    LsmSvgRadialGradientElementAttributes *attributes,
+						    GSList **elements)
 {
 	LsmSvgGradientElement *referenced_gradient = gradient;
 	LsmDomElement *element;
 
+	*elements = g_slist_prepend (*elements, gradient);
+
 	if (lsm_attribute_is_defined (&gradient->href)) {
 		char *id;
+		GSList *iter;
+		gboolean circular_reference_found = FALSE;
 
 		id = gradient->href.value;
 		if (id == NULL)
@@ -83,21 +88,31 @@ lsm_svg_radial_gradient_element_inherit_referenced (LsmDomDocument *owner,
 			id++;
 
 		element = lsm_dom_document_get_element_by_id (owner, id);
-		if (LSM_IS_SVG_GRADIENT_ELEMENT (element)) {
-			lsm_debug ("render",
-				   "[LsmSvgRadialGradientElement::inherit_attributes]"
-				   " Found referenced element '%s'", id);
 
-			referenced_gradient = lsm_svg_radial_gradient_element_inherit_referenced
-				(owner,
-				 LSM_SVG_GRADIENT_ELEMENT (element),
-				 attributes);
-		} else {
-			lsm_debug ("render",
-				   "[LsmSvgRadialGradientElement::inherit_attributes]"
-				   " Referenced element '%s' not found", id);
+		for (iter = *elements; iter != NULL; iter = iter->next)
+			if (iter->data == element) {
+				lsm_debug_render ("[LsmSvgRadialGradientElement::inherit_attributes] "
+					   "Circular reference (id = %s)", id);
+				circular_reference_found = TRUE;
+			}
+
+		if (!circular_reference_found) {
+			if (LSM_IS_SVG_GRADIENT_ELEMENT (element)) {
+				lsm_debug_render ("[LsmSvgRadialGradientElement::inherit_attributes]"
+						  " Found referenced element '%s'", id);
+
+				referenced_gradient = lsm_svg_radial_gradient_element_inherit_referenced
+					(owner,
+					 LSM_SVG_GRADIENT_ELEMENT (element),
+					 attributes, elements);
+			} else {
+				lsm_debug_render ("[LsmSvgRadialGradientElement::inherit_attributes]"
+						  " Referenced element '%s' not found", id);
+				referenced_gradient = NULL;
+			}
+		} else
 			referenced_gradient = NULL;
-		}
+
 	}
 
 	if (LSM_IS_SVG_RADIAL_GRADIENT_ELEMENT (gradient)) {
@@ -145,11 +160,14 @@ lsm_svg_radial_gradient_element_create_gradient (LsmSvgElement *self,
 		LsmSvgRadialGradientElementAttributes attributes;
 		LsmDomDocument *owner;
 		attributes = default_attributes;
+		GSList *elements = NULL;
 
 		owner = lsm_dom_node_get_owner_document (LSM_DOM_NODE (self));
 
 		referenced_gradient = lsm_svg_radial_gradient_element_inherit_referenced
-			(owner, LSM_SVG_GRADIENT_ELEMENT (gradient), &attributes);
+			(owner, LSM_SVG_GRADIENT_ELEMENT (gradient), &attributes, &elements);
+
+		g_slist_free (elements);
 
 		gradient->cx.length = attributes.cx;
 		gradient->cy.length = attributes.cy;
@@ -209,7 +227,7 @@ lsm_svg_radial_gradient_element_create_gradient (LsmSvgElement *self,
 	if (is_object_bounding_box)
 		lsm_svg_view_pop_viewbox (view);
 
-	lsm_debug ("render", "[LsmSvgRadialElement::render] cx = %g, cy = %g, r = %g, fx = %g, fy = %g",
+	lsm_debug_render ("[LsmSvgRadialElement::render] cx = %g, cy = %g, r = %g, fx = %g, fy = %g",
 		    cx, cy, r, fx, fy);
 
 	lsm_svg_view_create_radial_gradient (view, cx, cy, r, fx, fy);
