@@ -1,4 +1,5 @@
-/*
+/* Lasem - SVG and Mathml library
+ *
  * Copyright © 2009 Emmanuel Pacaud
  *
  * This library is free software; you can redistribute it and/or
@@ -23,7 +24,7 @@
 #include <lsmsvgstyle.h>
 #include <lsmsvgcolors.h>
 #include <lsmsvgtraits.h>
-#include <lsmstr.h>
+#include <lsm.h>
 #include <string.h>
 #include <math.h>
 
@@ -182,7 +183,7 @@ static const LsmPropertyInfos lsm_svg_property_infos[] = {
 	{
 		.name = "display",
 		.id = LSM_PROPERTY_OFFSET_TO_ID (LsmSvgStyle, display),
-		.trait_class = &lsm_null_trait_class,
+		.trait_class = &lsm_svg_display_trait_class,
 		.trait_default = "inline"
 	},
 	{
@@ -380,7 +381,7 @@ static const LsmPropertyInfos lsm_svg_property_infos[] = {
 	{
 		.name = "visibility",
 		.id = LSM_PROPERTY_OFFSET_TO_ID (LsmSvgStyle, visibility),
-		.trait_class = &lsm_null_trait_class,
+		.trait_class = &lsm_svg_visibility_trait_class,
 		.trait_default = "visible"
 	},
 	{
