@@ -1,19 +1,20 @@
 /*
  * Copyright © 2009 Emmanuel Pacaud
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
+ * You should have received a copy of the GNU Lesser General
+ * Public License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
+ * Boston, MA 02111-1307, USA.
  *
  * Author:
  * 	Emmanuel Pacaud <emmanuel@gnome.org>
@@ -22,7 +23,7 @@
 #ifndef LSM_SVG_SVG_ELEMENT_H
 #define LSM_SVG_SVG_ELEMENT_H
 
-#include <lsmsvg.h>
+#include <lsmsvgtypes.h>
 #include <lsmsvgelement.h>
 
 G_BEGIN_DECLS
@@ -60,7 +61,8 @@ GType lsm_svg_svg_element_get_type (void);
 
 LsmDomNode *		lsm_svg_svg_element_new 		(void);
 
-void 			lsm_svg_svg_element_measure 		(LsmSvgSvgElement *self, double *width, double *height);
+void 			lsm_svg_svg_element_measure 		(LsmSvgSvgElement *self,
+								 LsmSvgView *view, double *width, double *height);
 void 			lsm_svg_svg_element_render 		(LsmSvgSvgElement *svg_element, LsmSvgView *view);
 
 G_END_DECLS
