@@ -47,7 +47,7 @@ lsm_svg_use_can_append_child (LsmDomNode *node, LsmDomNode *child)
 /* LsmSvgGraphic implementation */
 
 static LsmDomElement *
-_get_used_element (LsmSvgUseElement *use_element, const char *domain)
+_get_used_element (LsmSvgUseElement *use_element)
 {
 	LsmDomDocument *document;
 	LsmDomElement *element;
@@ -55,7 +55,7 @@ _get_used_element (LsmSvgUseElement *use_element, const char *domain)
 
 	document = lsm_dom_node_get_owner_document (LSM_DOM_NODE (use_element));
 	if (document == NULL) {
-		lsm_debug (domain, "[LsmSvgUseElement::_get_used_element] Owner document not found");
+		lsm_debug_dom ("[LsmSvgUseElement::_get_used_element] Owner document not found");
 		return NULL;
 	}
 
@@ -68,7 +68,7 @@ _get_used_element (LsmSvgUseElement *use_element, const char *domain)
 
 	element = lsm_dom_document_get_element_by_id (document, id);
 	if (!LSM_IS_SVG_ELEMENT (element)) {
-		lsm_debug (domain, "[LsmSvgUseElement::_get_used_element] Target '%s' not found", id);
+		lsm_debug_dom ("[LsmSvgUseElement::_get_used_element] Target '%s' not found", id);
 		return NULL;
 	}
 
@@ -83,10 +83,17 @@ lsm_svg_use_element_render (LsmSvgElement *self, LsmSvgView *view)
 	LsmSvgMatrix matrix;
 	double x, y;
 
-	element = _get_used_element (use_element, "render");
+	if (use_element->flags & LSM_SVG_USE_ELEMENT_FLAGS_IN_USE_FOR_RENDER) {
+		lsm_debug_render ("[LsmSvgUseElement::render] Circular reference");
+		return;
+	}
+
+	element = _get_used_element (use_element);
 	if (element == NULL)
 		return;
 
+	use_element->flags |= LSM_SVG_USE_ELEMENT_FLAGS_IN_USE_FOR_RENDER;
+
 	x = lsm_svg_view_normalize_length (view, &use_element->x.length,
 					   LSM_SVG_LENGTH_DIRECTION_HORIZONTAL);
 	y = lsm_svg_view_normalize_length (view, &use_element->y.length,
@@ -98,6 +105,8 @@ lsm_svg_use_element_render (LsmSvgElement *self, LsmSvgView *view)
 	lsm_svg_element_render (LSM_SVG_ELEMENT (element), view);
 
 	lsm_svg_view_pop_matrix (view);
+
+	use_element->flags &= ~LSM_SVG_USE_ELEMENT_FLAGS_IN_USE_FOR_RENDER;
 }
 
 static void
@@ -108,7 +117,16 @@ lsm_svg_use_element_get_extents (LsmSvgElement *self, LsmSvgView *view, LsmExten
 	LsmSvgMatrix matrix;
 	double x, y;
 
-	element = _get_used_element (use_element, "render");
+	if (use_element->flags & LSM_SVG_USE_ELEMENT_FLAGS_IN_USE_FOR_GET_EXTENTS) {
+		lsm_debug_render ("[LsmSvgUseElement::get_extents] Circular reference");
+		extents->x1 = 0;
+		extents->y1 = 0;
+		extents->x2 = 0;
+		extents->y2 = 0;
+		return;
+	}
+
+	element = _get_used_element (use_element);
 	if (element == NULL) {
 		extents->x1 = 0;
 		extents->y1 = 0;
@@ -117,6 +135,8 @@ lsm_svg_use_element_get_extents (LsmSvgElement *self, LsmSvgView *view, LsmExten
 		return;
 	}
 
+	use_element->flags |= LSM_SVG_USE_ELEMENT_FLAGS_IN_USE_FOR_GET_EXTENTS;
+
 	x = lsm_svg_view_normalize_length (view, &use_element->x.length,
 					   LSM_SVG_LENGTH_DIRECTION_HORIZONTAL);
 	y = lsm_svg_view_normalize_length (view, &use_element->y.length,
@@ -137,6 +157,8 @@ lsm_svg_use_element_get_extents (LsmSvgElement *self, LsmSvgView *view, LsmExten
 					       &extents->x2, &extents->y2);
 
 	lsm_svg_view_pop_matrix (view);
+
+	use_element->flags &= ~LSM_SVG_USE_ELEMENT_FLAGS_IN_USE_FOR_GET_EXTENTS;
 }
 
 /* LsmSvgUseElement implementation */
