@@ -1,4 +1,5 @@
-/*
+/* Lasem - SVG and Mathml library
+ *
  * Copyright © 2009 Emmanuel Pacaud
  *
  * This library is free software; you can redistribute it and/or
@@ -23,9 +24,9 @@
 #ifndef LSM_SVG_VIEW_H
 #define LSM_SVG_VIEW_H
 
-#include <lsmdomview.h>
+#include <lsmdom.h>
+#include <lsmsvgtypes.h>
 #include <lsmsvgelement.h>
-#include <lsmsvg.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 
 G_BEGIN_DECLS
@@ -58,8 +59,12 @@ struct _LsmSvgView {
 	GSList *element_stack;
 	GSList *viewbox_stack;
 	GSList *matrix_stack;
+	GSList *pango_layout_stack;
+
+	gboolean is_pango_layout_in_use;
 
 	LsmSvgViewPatternData *pattern_data;
+	PangoLayout *pango_layout;
 
 	GSList *pattern_stack;
 
@@ -67,6 +72,8 @@ struct _LsmSvgView {
 	LsmBox clip_extents;
 
 	double last_stop_offset;
+
+	GSList *filter_surfaces;
 };
 
 struct _LsmSvgViewClass {
@@ -83,6 +90,10 @@ double 		lsm_svg_view_normalize_length 		(LsmSvgView *view, const LsmSvgLength *
 const LsmBox *	lsm_svg_view_get_pattern_extents	(LsmSvgView *view);
 const LsmBox *	lsm_svg_view_get_clip_extents		(LsmSvgView *view);
 
+void		lsm_svg_view_calculate_path_extents	(LsmSvgView *view, const char *path,
+							 double *x1, double *y1,
+							 double *x2, double *y2);
+
 void 		lsm_svg_view_create_radial_gradient 	(LsmSvgView *view, double cx, double cy,
 							                   double r, double fx, double fy);
 void 		lsm_svg_view_create_linear_gradient 	(LsmSvgView *view, double x1, double y1,
@@ -93,11 +104,9 @@ void 		lsm_svg_view_set_gradient_properties	(LsmSvgView *view,
 							 LsmSvgPatternUnits units,
 							 const LsmSvgMatrix *matrix);
 
-void		lsm_svg_view_create_surface_pattern	(LsmSvgView *view, const LsmBox *viewport,
-							 LsmSvgPatternUnits units,
-							 LsmSvgPatternUnits content_units,
+gboolean	lsm_svg_view_create_surface_pattern	(LsmSvgView *view, const LsmBox *viewport,
 							 const LsmSvgMatrix *matrix,
-							 LsmSvgViewSurfaceType surface_type);
+							 LsmSvgViewSurfaceType surface_type) G_GNUC_WARN_UNUSED_RESULT;
 
 void 		lsm_svg_view_show_rectangle 	(LsmSvgView *view, double x, double y,
 						                   double width, double height,
@@ -135,6 +144,9 @@ void		lsm_svg_view_pop_style			(LsmSvgView *view);
 
 LsmSvgStyle *	lsm_svg_view_get_current_style	(LsmSvgView *view);
 
+void		lsm_svg_view_apply_gaussian_blur 	(LsmSvgView *view, const char *input, const char *output,
+							 double x, double y, double w, double h,
+							 double std_x, double std_y);
 G_END_DECLS
 
 #endif
